@@ -20,33 +20,39 @@ def main():
 @main.command(name='azure')
 @click.argument('target', default='help')
 @click.argument('args', nargs=-1)
-def azure(target, args):
+@click.option('--dry-run', is_flag=True, default=False)
+@click.option('--workspace-key-prefix')
+def azure(target:str, args:list, dry_run:bool, workspace_key_prefix:str):
     '''
     Use Azure provider
     '''
-    DefaultCommandHandler('azure').call(target, args)
+    DefaultCommandHandler('azure').call(target, args, dry_run, workspace_key_prefix)
 
 @main.command(name='guess', default_command=True)
 @click.argument('target', default='help')
 @click.argument('args', nargs=-1)
-def guess(target, args):
+@click.option('--dry-run', is_flag=True, default=False)
+@click.option('--workspace-key-prefix')
+def guess(target:str, args:list, dry_run:bool, workspace_key_prefix:str):
     '''
     Default command that guesses what provider you're using.
     '''
-    DefaultCommandHandler().call(target, args)
+    DefaultCommandHandler().call(target, args, dry_run, workspace_key_prefix)
 
 @main.command(name='aws')
 @click.argument('target', default='help')
 @click.argument('args', nargs=-1)
-def aws(target, args):
+@click.option('--dry-run', is_flag=True, default=False)
+@click.option('--workspace-key-prefix')
+def aws(target:str, args:list, dry_run:bool, workspace_key_prefix:str):
     '''
     Use AWS provider.
     '''
-    DefaultCommandHandler('aws').call(target, args)
+    DefaultCommandHandler('aws').call(target, args, dry_run, workspace_key_prefix)
 
 @main.command()
 @click.argument('provider', default='aws')
-def init(provider):
+def init(provider:str):
     '''
     Create configuration for provider (migrate if needed).
     '''
@@ -56,7 +62,8 @@ def init(provider):
         if click.confirm('Legacy configuration found! Do you want me to migrate?', default=True):
             with open(cwd,'r') as f:
                 legacy = f.read()
-            os.rename(cwd, '{}.bkp'.format(cwd))
+
+        os.rename(cwd, '{}.bkp'.format(cwd))
 
     if not os.path.isdir(cwd):
         os.mkdir(cwd)
@@ -73,7 +80,7 @@ def init(provider):
     with open(config, 'w+') as f:
         f.write(contents)
 
-    if os.path.isfile('{}.bkp'.format(cwd)):
+    if legacy and os.path.isfile('{}.bkp'.format(cwd)):
         if click.confirm('\n\nSuccessfully migrated configuration. Delete backup?', default=True):
             os.remove('{}.bkp'.format(cwd))
 
